@@ -25,7 +25,7 @@ Usage::
     list_findings_paginator: ListFindingsPaginator = client.get_paginator("list_findings")
     ```
 """
-from mypy_boto3_accessanalyzer.client import AccessAnalyzerClient, AccessAnalyzerClient as Client
+from mypy_boto3_accessanalyzer.client import AccessAnalyzerClient
 from mypy_boto3_accessanalyzer.paginator import (
     ListAnalyzedResourcesPaginator,
     ListAnalyzersPaginator,
@@ -33,6 +33,8 @@ from mypy_boto3_accessanalyzer.paginator import (
     ListFindingsPaginator,
 )
 
+Client = AccessAnalyzerClient
+
 
 __all__ = (
     "AccessAnalyzerClient",
